// buildlib.cpp : Defines the entry point for the console application.
//

#include "stdafx.h"
#include <stdio.h>
#include <memory.h>
#include <string.h>
#include "fileformatdefs.h"
#include "groupfile.h"
#include "mapfile.h"
#include "artfile.h"
#include "palettefile.h"

int main(int argc, char* argv[])
{
	if(argc > 1)
	{

		GroupFile* pGrpFile = new GroupFile(argv[1]);
		if( pGrpFile->GetStatus() == 0)
		{
			printf("GRP Filename: %s\n", pGrpFile->GetFileName());
			printf("Number of files in this archive: %d\n", pGrpFile->GetNumFiles());
			uint32 nNumFiles = pGrpFile->GetNumFiles();

			for(uint32 i = 0; i < nNumFiles; i++)
			{
				
				FILESTRUCT *pFileEntry = pGrpFile->GetFileEntry(i);
				
				if(pFileEntry)
				{
					char sPrintableFilename[13];
					memset(sPrintableFilename, 0, 12);
					strncpy(sPrintableFilename, pFileEntry->fileheader.name, 12);
					sPrintableFilename[12] = '\0';
					
					//Print out some info on each file entry
					//printf("[%d] %s  Size: %d\n", i, sPrintableFilename, pFileEntry->fileheader.size);


					//
					// Test the .ART support
					//
					if( strcmp("TILES000.ART", sPrintableFilename) == 0)
					{
						ArtFile *_artfile = new ArtFile(pFileEntry);

						printf("\n------------------\n");
						printf("  ART FILE TEST\n");
						printf("------------------\n");
						printf("ArtFile: %s  Size: %d\n", sPrintableFilename, pFileEntry->fileheader.size);
						printf("Version: %d \n", _artfile->GetVersion());
						printf("NumTiles: %d\n", _artfile->GetNumTiles());
						printf("TileStart: %d\n", _artfile->GetTileStart());
						printf("TileEnd: %d\n", _artfile->GetTileEnd());

						printf("\n");

						/*
						//print each tiles dims
						for(uint32 j = 0; j < _artfile->GetNumTiles(); j++)
						{
							printf("Tile [%d] X: %d  Y: %d\n", j, _artfile->GetTileSizeX(j), _artfile->GetTileSizeY(j));
						}
						*/


						if(_artfile)
						delete _artfile;
					}

					//
					// Test the .MAP support
					//
					if( strcmp("E1L8.MAP", pFileEntry->fileheader.name) == 0)
					{

						MapFile *_map = new MapFile(pFileEntry);
						
						printf("------------------\n");
						printf("  MAP FILE TEST\n");
						printf("------------------\n");
						printf("Map: %s  Size: %d\n", sPrintableFilename, pFileEntry->fileheader.size);
						printf("Version: %d\n", _map->GetVersion());
						Pos pos = _map->GetStartPosition();
						printf("Start position: %d %d %d\n", pos.x, pos.y, pos.z);
						printf("Start Angle: %d\n", _map->GetStartAngle());
						printf("Startpoint Sector: %d\n", _map->GetStartSectorNum());						
						printf("Sectors: %d\n", _map->GetNumSectors());
						printf("Walls: %d\n", _map->GetNumWalls());
						printf("Sprites: %d\n", _map->GetNumSprites());

						delete _map;

					}
					
					
					if( strcmp("PALETTE.DAT", pFileEntry->fileheader.name) == 0)
					{
																	
						PaletteFile *_palette = new PaletteFile(pFileEntry);
						
						printf("---------------------\n");
						printf("  PALETTE FILE TEST\n");
						printf("---------------------\n");	
						printf("Palette: %s  Size: %d\n", sPrintableFilename, pFileEntry->fileheader.size);						
						printf("Number of palette lookups: : %d\n", _palette->GetNumPalLookups());
						
						if(_palette)
							delete _palette;
					}
					//
					// This code extracts all the files from the GRP file
					//
					/*
					//extract the file
					char sFilename[128];
					sprintf(sFilename, "test\\%s", pFileEntry->fileheader.name);

					FILE* fp;
					fp = fopen(sFilename, "wb");
					if(fp != NULL)
					{
						fwrite(&pFileEntry->data[0], sizeof(char), pFileEntry->fileheader.size, fp);
						fflush(fp);
						fclose(fp);
					}
					*/

					
					
				}
				
			}
			/*
			// Save Grp file
					pGrpFile->SetFilename("test.grp");
					pGrpFile->Save();
			*/
		}

		//Finish
		if(pGrpFile)
		{
			delete pGrpFile;
		}

	}
	return 0;
}

